"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const processor_1 = require("./processor");
const defaults_1 = require("../../defaults");
function readEntry(entry, config) {
    let { resolveTemplateFile, templatesPath, info, error } = config;
    info = info || defaults_1.defaults.info;
    error = error || defaults_1.defaults.error;
    info('readEntry', {
        entry
    });
    if (!resolveTemplateFile) {
        error('readEntry: missing resolveTemplateFile function', {
            config
        });
    }
    const templateFilePath = resolveTemplateFile(entry);
    if (!templateFilePath) {
        error('readEntry: templateFilePath not resolved', {
            templateFilePath,
            entry,
            resolveTemplateFile: resolveTemplateFile.toString()
        });
    }
    info('readEntry: resolved', {
        templateFilePath
    });
    const processorCfg = {
        templateFilePath,
        templatesPath,
        entry,
        info
    };
    const processFile = processor_1.createFileProcessor(processorCfg);
    if (!processFile) {
        error('readEntry: processFile not created', {
            processFile,
            processorCfg
        });
    }
    return processFile().then((data) => {
        entry.data = data;
        return entry;
    });
}
exports.readEntry = readEntry;
//# sourceMappingURL=reader.js.map