"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const defaults_1 = require("../../defaults");
const processor_1 = require("./processor");
function renderEntry(entry, config) {
    let { resolveTemplateFile, templatesPath, renderTemplate, info, error } = config;
    info = info || defaults_1.defaults.info;
    error = error || defaults_1.defaults.error;
    info('renderEntry', {
        entry,
    });
    if (!resolveTemplateFile) {
        error('renderEntry: missing resolveTemplateFile function', {
            config
        });
    }
    if (!renderTemplate) {
        error('renderEntry: missing renderTemplate function', {
            config
        });
    }
    const templateFilePath = resolveTemplateFile(entry);
    if (!templateFilePath) {
        error('readEntry: templateFilePath not resolved', {
            templateFilePath,
            entry,
            resolveTemplateFile: resolveTemplateFile.toString()
        });
    }
    info('renderEntry: resolved', {
        templateFilePath
    });
    const processorCfg = {
        renderTemplate,
        templateFilePath,
        templatesPath,
        entry,
        info
    };
    const processTemplate = processor_1.createTemplateProcessor(processorCfg);
    if (!processTemplate) {
        error('renderEntry: processTemplate not created', {
            processTemplate,
            processorCfg
        });
    }
    return processTemplate().then((data) => {
        entry.data = data;
        return entry;
    });
}
exports.renderEntry = renderEntry;
//# sourceMappingURL=renderer.js.map