"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function createNotifiers(options) {
    const { warnOn, infoOn, errorOn = true, logger = console } = options;
    function logErr(msg, data) {
        if (!errorOn)
            return;
        data ? logger.error(msg, data) : logger.error(msg);
    }
    function log(msg, data) {
        data ? logger.log(msg, data) : logger.log(msg);
    }
    function info(msg, data) {
        if (!infoOn)
            return;
        log(msg, data);
    }
    function warn(msg, data) {
        if (!warnOn)
            return;
        logErr(msg);
    }
    function error(msg, data) {
        logErr(msg, data);
        throw new Error(msg);
    }
    return {
        warn,
        error,
        info
    };
}
exports.createNotifiers = createNotifiers;
//# sourceMappingURL=notifiers.js.map